# coding: utf-8

# flake8: noqa

"""
    Qdrant API

    API description for Qdrant vector search engine.  This document describes CRUD and search operations on collections of points (vectors with payload).  Qdrant supports any combinations of `should`, `must` and `must_not` conditions, which makes it possible to use in applications when object could not be described solely by vector. It could be location features, availability flags, and other custom properties businesses should take into account. ## Examples This examples cover the most basic use-cases - collection creation and basic vector search. ### Create collection First - let's create a collection with dot-production metric. ``` curl -X PUT 'http://localhost:6333/collections/test_collection' \\   -H 'Content-Type: application/json' \\   --data-raw '{     \"vectors\": {       \"size\": 4,       \"distance\": \"Dot\"     }   }'  ``` Expected response: ``` {     \"result\": true,     \"status\": \"ok\",     \"time\": 0.031095451 } ``` We can ensure that collection was created: ``` curl 'http://localhost:6333/collections/test_collection' ``` Expected response: ``` {   \"result\": {     \"status\": \"green\",     \"vectors_count\": 0,     \"segments_count\": 5,     \"disk_data_size\": 0,     \"ram_data_size\": 0,     \"config\": {       \"params\": {         \"vectors\": {           \"size\": 4,           \"distance\": \"Dot\"         }       },       \"hnsw_config\": {         \"m\": 16,         \"ef_construct\": 100,         \"full_scan_threshold\": 10000       },       \"optimizer_config\": {         \"deleted_threshold\": 0.2,         \"vacuum_min_vector_number\": 1000,         \"max_segment_number\": 5,         \"memmap_threshold\": 50000,         \"indexing_threshold\": 20000,         \"flush_interval_sec\": 1       },       \"wal_config\": {         \"wal_capacity_mb\": 32,         \"wal_segments_ahead\": 0       }     }   },   \"status\": \"ok\",   \"time\": 2.1199e-05 } ```  ### Add points Let's now add vectors with some payload: ``` curl -L -X PUT 'http://localhost:6333/collections/test_collection/points?wait=true' \\ -H 'Content-Type: application/json' \\ --data-raw '{   \"points\": [     {\"id\": 1, \"vector\": [0.05, 0.61, 0.76, 0.74], \"payload\": {\"city\": \"Berlin\"}},     {\"id\": 2, \"vector\": [0.19, 0.81, 0.75, 0.11], \"payload\": {\"city\": [\"Berlin\", \"London\"] }},     {\"id\": 3, \"vector\": [0.36, 0.55, 0.47, 0.94], \"payload\": {\"city\": [\"Berlin\", \"Moscow\"] }},     {\"id\": 4, \"vector\": [0.18, 0.01, 0.85, 0.80], \"payload\": {\"city\": [\"London\", \"Moscow\"] }},     {\"id\": 5, \"vector\": [0.24, 0.18, 0.22, 0.44], \"payload\": {\"count\": [0]}},     {\"id\": 6, \"vector\": [0.35, 0.08, 0.11, 0.44]}   ] }' ``` Expected response: ``` {     \"result\": {         \"operation_id\": 0,         \"status\": \"completed\"     },     \"status\": \"ok\",     \"time\": 0.000206061 } ``` ### Search with filtering Let's start with a basic request: ``` curl -L -X POST 'http://localhost:6333/collections/test_collection/points/search' \\ -H 'Content-Type: application/json' \\ --data-raw '{     \"vector\": [0.2,0.1,0.9,0.7],     \"top\": 3 }' ``` Expected response: ``` {     \"result\": [         { \"id\": 4, \"score\": 1.362, \"payload\": null, \"version\": 0 },         { \"id\": 1, \"score\": 1.273, \"payload\": null, \"version\": 0 },         { \"id\": 3, \"score\": 1.208, \"payload\": null, \"version\": 0 }     ],     \"status\": \"ok\",     \"time\": 0.000055785 } ``` But result is different if we add a filter: ``` curl -L -X POST 'http://localhost:6333/collections/test_collection/points/search' \\ -H 'Content-Type: application/json' \\ --data-raw '{     \"filter\": {         \"should\": [             {                 \"key\": \"city\",                 \"match\": {                     \"value\": \"London\"                 }             }         ]     },     \"vector\": [0.2, 0.1, 0.9, 0.7],     \"top\": 3 }' ``` Expected response: ``` {     \"result\": [         { \"id\": 4, \"score\": 1.362, \"payload\": null, \"version\": 0 },         { \"id\": 2, \"score\": 0.871, \"payload\": null, \"version\": 0 }     ],     \"status\": \"ok\",     \"time\": 0.000093972 } ``` 

    The version of the OpenAPI document: v1.7.x
    Contact: andrey@vasnetsov.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# import apis into sdk package
from qdrant_openapi.api.cluster_api import ClusterApi
from qdrant_openapi.api.collections_api import CollectionsApi
from qdrant_openapi.api.points_api import PointsApi
from qdrant_openapi.api.service_api import ServiceApi
from qdrant_openapi.api.snapshots_api import SnapshotsApi

# import ApiClient
from qdrant_openapi.api_response import ApiResponse
from qdrant_openapi.api_client import ApiClient
from qdrant_openapi.configuration import Configuration
from qdrant_openapi.exceptions import OpenApiException
from qdrant_openapi.exceptions import ApiTypeError
from qdrant_openapi.exceptions import ApiValueError
from qdrant_openapi.exceptions import ApiKeyError
from qdrant_openapi.exceptions import ApiAttributeError
from qdrant_openapi.exceptions import ApiException

# import models into sdk package
from qdrant_openapi.models.abort_transfer_operation import AbortTransferOperation
from qdrant_openapi.models.alias_description import AliasDescription
from qdrant_openapi.models.alias_operations import AliasOperations
from qdrant_openapi.models.any_variants import AnyVariants
from qdrant_openapi.models.app_build_telemetry import AppBuildTelemetry
from qdrant_openapi.models.app_features_telemetry import AppFeaturesTelemetry
from qdrant_openapi.models.batch import Batch
from qdrant_openapi.models.batch_payloads_inner import BatchPayloadsInner
from qdrant_openapi.models.batch_update200_response import BatchUpdate200Response
from qdrant_openapi.models.batch_vector_struct import BatchVectorStruct
from qdrant_openapi.models.binary_quantization import BinaryQuantization
from qdrant_openapi.models.binary_quantization_config import BinaryQuantizationConfig
from qdrant_openapi.models.change_aliases_operation import ChangeAliasesOperation
from qdrant_openapi.models.clear_payload_operation import ClearPayloadOperation
from qdrant_openapi.models.cluster_config_telemetry import ClusterConfigTelemetry
from qdrant_openapi.models.cluster_operations import ClusterOperations
from qdrant_openapi.models.cluster_status import ClusterStatus
from qdrant_openapi.models.cluster_status200_response import ClusterStatus200Response
from qdrant_openapi.models.cluster_status_one_of import ClusterStatusOneOf
from qdrant_openapi.models.cluster_status_one_of1 import ClusterStatusOneOf1
from qdrant_openapi.models.cluster_status_telemetry import ClusterStatusTelemetry
from qdrant_openapi.models.cluster_telemetry import ClusterTelemetry
from qdrant_openapi.models.collection_cluster_info import CollectionClusterInfo
from qdrant_openapi.models.collection_cluster_info200_response import CollectionClusterInfo200Response
from qdrant_openapi.models.collection_config import CollectionConfig
from qdrant_openapi.models.collection_description import CollectionDescription
from qdrant_openapi.models.collection_info import CollectionInfo
from qdrant_openapi.models.collection_params import CollectionParams
from qdrant_openapi.models.collection_params_diff import CollectionParamsDiff
from qdrant_openapi.models.collection_status import CollectionStatus
from qdrant_openapi.models.collection_telemetry import CollectionTelemetry
from qdrant_openapi.models.collection_telemetry_enum import CollectionTelemetryEnum
from qdrant_openapi.models.collections_aggregated_telemetry import CollectionsAggregatedTelemetry
from qdrant_openapi.models.collections_aliases_response import CollectionsAliasesResponse
from qdrant_openapi.models.collections_response import CollectionsResponse
from qdrant_openapi.models.collections_telemetry import CollectionsTelemetry
from qdrant_openapi.models.compression_ratio import CompressionRatio
from qdrant_openapi.models.condition import Condition
from qdrant_openapi.models.consensus_config_telemetry import ConsensusConfigTelemetry
from qdrant_openapi.models.consensus_thread_status import ConsensusThreadStatus
from qdrant_openapi.models.consensus_thread_status_one_of import ConsensusThreadStatusOneOf
from qdrant_openapi.models.consensus_thread_status_one_of1 import ConsensusThreadStatusOneOf1
from qdrant_openapi.models.consensus_thread_status_one_of2 import ConsensusThreadStatusOneOf2
from qdrant_openapi.models.context_example_pair import ContextExamplePair
from qdrant_openapi.models.count_points200_response import CountPoints200Response
from qdrant_openapi.models.count_request import CountRequest
from qdrant_openapi.models.count_result import CountResult
from qdrant_openapi.models.create_alias import CreateAlias
from qdrant_openapi.models.create_alias_operation import CreateAliasOperation
from qdrant_openapi.models.create_collection import CreateCollection
from qdrant_openapi.models.create_field_index import CreateFieldIndex
from qdrant_openapi.models.create_field_index200_response import CreateFieldIndex200Response
from qdrant_openapi.models.create_shard_key200_response import CreateShardKey200Response
from qdrant_openapi.models.create_sharding_key import CreateShardingKey
from qdrant_openapi.models.create_sharding_key_operation import CreateShardingKeyOperation
from qdrant_openapi.models.create_snapshot200_response import CreateSnapshot200Response
from qdrant_openapi.models.delete_alias import DeleteAlias
from qdrant_openapi.models.delete_alias_operation import DeleteAliasOperation
from qdrant_openapi.models.delete_operation import DeleteOperation
from qdrant_openapi.models.delete_payload import DeletePayload
from qdrant_openapi.models.delete_payload_operation import DeletePayloadOperation
from qdrant_openapi.models.delete_vectors import DeleteVectors
from qdrant_openapi.models.delete_vectors_operation import DeleteVectorsOperation
from qdrant_openapi.models.disabled import Disabled
from qdrant_openapi.models.discover_request import DiscoverRequest
from qdrant_openapi.models.discover_request_batch import DiscoverRequestBatch
from qdrant_openapi.models.distance import Distance
from qdrant_openapi.models.drop_replica_operation import DropReplicaOperation
from qdrant_openapi.models.drop_sharding_key import DropShardingKey
from qdrant_openapi.models.drop_sharding_key_operation import DropShardingKeyOperation
from qdrant_openapi.models.error_response import ErrorResponse
from qdrant_openapi.models.error_response_status import ErrorResponseStatus
from qdrant_openapi.models.extended_point_id import ExtendedPointId
from qdrant_openapi.models.field_condition import FieldCondition
from qdrant_openapi.models.filter import Filter
from qdrant_openapi.models.filter_selector import FilterSelector
from qdrant_openapi.models.geo_bounding_box import GeoBoundingBox
from qdrant_openapi.models.geo_line_string import GeoLineString
from qdrant_openapi.models.geo_point import GeoPoint
from qdrant_openapi.models.geo_polygon import GeoPolygon
from qdrant_openapi.models.geo_radius import GeoRadius
from qdrant_openapi.models.get_collection200_response import GetCollection200Response
from qdrant_openapi.models.get_collection_aliases200_response import GetCollectionAliases200Response
from qdrant_openapi.models.get_collections200_response import GetCollections200Response
from qdrant_openapi.models.get_locks200_response import GetLocks200Response
from qdrant_openapi.models.get_point200_response import GetPoint200Response
from qdrant_openapi.models.get_points200_response import GetPoints200Response
from qdrant_openapi.models.group_id import GroupId
from qdrant_openapi.models.groups_result import GroupsResult
from qdrant_openapi.models.grpc_telemetry import GrpcTelemetry
from qdrant_openapi.models.has_id_condition import HasIdCondition
from qdrant_openapi.models.hnsw_config import HnswConfig
from qdrant_openapi.models.hnsw_config_diff import HnswConfigDiff
from qdrant_openapi.models.indexes import Indexes
from qdrant_openapi.models.indexes_one_of import IndexesOneOf
from qdrant_openapi.models.indexes_one_of1 import IndexesOneOf1
from qdrant_openapi.models.init_from import InitFrom
from qdrant_openapi.models.is_empty_condition import IsEmptyCondition
from qdrant_openapi.models.is_null_condition import IsNullCondition
from qdrant_openapi.models.list_snapshots200_response import ListSnapshots200Response
from qdrant_openapi.models.local_shard_info import LocalShardInfo
from qdrant_openapi.models.local_shard_telemetry import LocalShardTelemetry
from qdrant_openapi.models.locks_option import LocksOption
from qdrant_openapi.models.lookup_location import LookupLocation
from qdrant_openapi.models.match import Match
from qdrant_openapi.models.match_any import MatchAny
from qdrant_openapi.models.match_except import MatchExcept
from qdrant_openapi.models.match_text import MatchText
from qdrant_openapi.models.match_value import MatchValue
from qdrant_openapi.models.message_send_errors import MessageSendErrors
from qdrant_openapi.models.move_shard import MoveShard
from qdrant_openapi.models.move_shard_operation import MoveShardOperation
from qdrant_openapi.models.named_sparse_vector import NamedSparseVector
from qdrant_openapi.models.named_vector import NamedVector
from qdrant_openapi.models.named_vector_struct import NamedVectorStruct
from qdrant_openapi.models.nested import Nested
from qdrant_openapi.models.nested_condition import NestedCondition
from qdrant_openapi.models.operation_duration_statistics import OperationDurationStatistics
from qdrant_openapi.models.optimizer_telemetry import OptimizerTelemetry
from qdrant_openapi.models.optimizers_config import OptimizersConfig
from qdrant_openapi.models.optimizers_config_diff import OptimizersConfigDiff
from qdrant_openapi.models.optimizers_status import OptimizersStatus
from qdrant_openapi.models.optimizers_status_one_of import OptimizersStatusOneOf
from qdrant_openapi.models.overwrite_payload_operation import OverwritePayloadOperation
from qdrant_openapi.models.p2p_config_telemetry import P2pConfigTelemetry
from qdrant_openapi.models.payload_field import PayloadField
from qdrant_openapi.models.payload_field_schema import PayloadFieldSchema
from qdrant_openapi.models.payload_index_info import PayloadIndexInfo
from qdrant_openapi.models.payload_index_telemetry import PayloadIndexTelemetry
from qdrant_openapi.models.payload_schema_type import PayloadSchemaType
from qdrant_openapi.models.payload_selector import PayloadSelector
from qdrant_openapi.models.payload_selector_exclude import PayloadSelectorExclude
from qdrant_openapi.models.payload_selector_include import PayloadSelectorInclude
from qdrant_openapi.models.payload_storage_type import PayloadStorageType
from qdrant_openapi.models.payload_storage_type_one_of import PayloadStorageTypeOneOf
from qdrant_openapi.models.payload_storage_type_one_of1 import PayloadStorageTypeOneOf1
from qdrant_openapi.models.peer_info import PeerInfo
from qdrant_openapi.models.point_group import PointGroup
from qdrant_openapi.models.point_ids_list import PointIdsList
from qdrant_openapi.models.point_insert_operations import PointInsertOperations
from qdrant_openapi.models.point_request import PointRequest
from qdrant_openapi.models.point_struct import PointStruct
from qdrant_openapi.models.point_vectors import PointVectors
from qdrant_openapi.models.points_batch import PointsBatch
from qdrant_openapi.models.points_list import PointsList
from qdrant_openapi.models.points_selector import PointsSelector
from qdrant_openapi.models.product_quantization import ProductQuantization
from qdrant_openapi.models.product_quantization_config import ProductQuantizationConfig
from qdrant_openapi.models.quantization_config import QuantizationConfig
from qdrant_openapi.models.quantization_config_diff import QuantizationConfigDiff
from qdrant_openapi.models.quantization_search_params import QuantizationSearchParams
from qdrant_openapi.models.raft_info import RaftInfo
from qdrant_openapi.models.range import Range
from qdrant_openapi.models.read_consistency import ReadConsistency
from qdrant_openapi.models.read_consistency_type import ReadConsistencyType
from qdrant_openapi.models.recommend_example import RecommendExample
from qdrant_openapi.models.recommend_groups_request import RecommendGroupsRequest
from qdrant_openapi.models.recommend_request import RecommendRequest
from qdrant_openapi.models.recommend_request_batch import RecommendRequestBatch
from qdrant_openapi.models.recommend_strategy import RecommendStrategy
from qdrant_openapi.models.record import Record
from qdrant_openapi.models.recover_from_uploaded_snapshot202_response import RecoverFromUploadedSnapshot202Response
from qdrant_openapi.models.remote_shard_info import RemoteShardInfo
from qdrant_openapi.models.remote_shard_telemetry import RemoteShardTelemetry
from qdrant_openapi.models.rename_alias import RenameAlias
from qdrant_openapi.models.rename_alias_operation import RenameAliasOperation
from qdrant_openapi.models.replica import Replica
from qdrant_openapi.models.replica_set_telemetry import ReplicaSetTelemetry
from qdrant_openapi.models.replica_state import ReplicaState
from qdrant_openapi.models.replicate_shard_operation import ReplicateShardOperation
from qdrant_openapi.models.requests_telemetry import RequestsTelemetry
from qdrant_openapi.models.running_environment_telemetry import RunningEnvironmentTelemetry
from qdrant_openapi.models.scalar_quantization import ScalarQuantization
from qdrant_openapi.models.scalar_quantization_config import ScalarQuantizationConfig
from qdrant_openapi.models.scalar_type import ScalarType
from qdrant_openapi.models.scored_point import ScoredPoint
from qdrant_openapi.models.scroll_points200_response import ScrollPoints200Response
from qdrant_openapi.models.scroll_request import ScrollRequest
from qdrant_openapi.models.scroll_result import ScrollResult
from qdrant_openapi.models.search_batch_points200_response import SearchBatchPoints200Response
from qdrant_openapi.models.search_groups_request import SearchGroupsRequest
from qdrant_openapi.models.search_params import SearchParams
from qdrant_openapi.models.search_point_groups200_response import SearchPointGroups200Response
from qdrant_openapi.models.search_points200_response import SearchPoints200Response
from qdrant_openapi.models.search_request import SearchRequest
from qdrant_openapi.models.search_request_batch import SearchRequestBatch
from qdrant_openapi.models.segment_config import SegmentConfig
from qdrant_openapi.models.segment_info import SegmentInfo
from qdrant_openapi.models.segment_telemetry import SegmentTelemetry
from qdrant_openapi.models.segment_type import SegmentType
from qdrant_openapi.models.set_payload import SetPayload
from qdrant_openapi.models.set_payload_operation import SetPayloadOperation
from qdrant_openapi.models.shard_key import ShardKey
from qdrant_openapi.models.shard_key_selector import ShardKeySelector
from qdrant_openapi.models.shard_snapshot_location import ShardSnapshotLocation
from qdrant_openapi.models.shard_snapshot_recover import ShardSnapshotRecover
from qdrant_openapi.models.shard_transfer_info import ShardTransferInfo
from qdrant_openapi.models.shard_transfer_method import ShardTransferMethod
from qdrant_openapi.models.sharding_method import ShardingMethod
from qdrant_openapi.models.snapshot_description import SnapshotDescription
from qdrant_openapi.models.snapshot_priority import SnapshotPriority
from qdrant_openapi.models.snapshot_recover import SnapshotRecover
from qdrant_openapi.models.sparse_index_config import SparseIndexConfig
from qdrant_openapi.models.sparse_index_params import SparseIndexParams
from qdrant_openapi.models.sparse_index_type import SparseIndexType
from qdrant_openapi.models.sparse_vector import SparseVector
from qdrant_openapi.models.sparse_vector_data_config import SparseVectorDataConfig
from qdrant_openapi.models.sparse_vector_params import SparseVectorParams
from qdrant_openapi.models.state_role import StateRole
from qdrant_openapi.models.telemetry200_response import Telemetry200Response
from qdrant_openapi.models.telemetry_data import TelemetryData
from qdrant_openapi.models.text_index_params import TextIndexParams
from qdrant_openapi.models.text_index_type import TextIndexType
from qdrant_openapi.models.tokenizer_type import TokenizerType
from qdrant_openapi.models.tracker_status import TrackerStatus
from qdrant_openapi.models.tracker_status_one_of import TrackerStatusOneOf
from qdrant_openapi.models.tracker_status_one_of1 import TrackerStatusOneOf1
from qdrant_openapi.models.tracker_telemetry import TrackerTelemetry
from qdrant_openapi.models.update_collection import UpdateCollection
from qdrant_openapi.models.update_operation import UpdateOperation
from qdrant_openapi.models.update_operations import UpdateOperations
from qdrant_openapi.models.update_result import UpdateResult
from qdrant_openapi.models.update_status import UpdateStatus
from qdrant_openapi.models.update_vectors import UpdateVectors
from qdrant_openapi.models.update_vectors_operation import UpdateVectorsOperation
from qdrant_openapi.models.upsert_operation import UpsertOperation
from qdrant_openapi.models.value_variants import ValueVariants
from qdrant_openapi.models.values_count import ValuesCount
from qdrant_openapi.models.vector import Vector
from qdrant_openapi.models.vector_data_config import VectorDataConfig
from qdrant_openapi.models.vector_data_info import VectorDataInfo
from qdrant_openapi.models.vector_index_searches_telemetry import VectorIndexSearchesTelemetry
from qdrant_openapi.models.vector_params import VectorParams
from qdrant_openapi.models.vector_params_diff import VectorParamsDiff
from qdrant_openapi.models.vector_storage_type import VectorStorageType
from qdrant_openapi.models.vector_struct import VectorStruct
from qdrant_openapi.models.vectors_config import VectorsConfig
from qdrant_openapi.models.wal_config import WalConfig
from qdrant_openapi.models.wal_config_diff import WalConfigDiff
from qdrant_openapi.models.web_api_telemetry import WebApiTelemetry
from qdrant_openapi.models.with_lookup import WithLookup
from qdrant_openapi.models.with_lookup_interface import WithLookupInterface
from qdrant_openapi.models.with_payload_interface import WithPayloadInterface
from qdrant_openapi.models.with_vector import WithVector
from qdrant_openapi.models.write_ordering import WriteOrdering
